==> basic-utils-4.0.0-20251204.100444-43-sources.jar: com/tydic/dyc/pro/base/utils/esb/DycProBaseCallEsbUtilGetSkuDetailForJdResultBO.java <==
package com.tydic.dyc.pro.base.utils.esb;

import lombok.Data;

import java.io.Serializable;
import java.util.List;

/**
 * @Author yuhao
 * @Date 2025/6/10 11:32
 * @Description:
 **/
@Data
public class DycProBaseCallEsbUtilGetSkuDetailForJdResultBO implements Serializable {

    private static final long serialVersionUID = 3007998057922435121L;
    /**
     * 品牌名称
     */
    private String brandName;
    /**
     * 主图
     */
    private String imagePath;
    /**
     * 属性信息
     */
    private List<DycProBaseCallEsbUtilSkuParamForJdBO> paramJson;
    /**
     * 商品最小起购量
     */
    private String LowestBuy;
    /**
     * 重量
     */
    private String weight;
    /**
     * 商品69条码
     */
    private String upc69;
    /**
     * UPC码区分实物、图书、音像、三种场景
     */
    private String upc;
    /**
     * 包装清单
     */
    private String wareQD;
    /**
     * 售卖计量单位
     */
    private String saleUnit;
    /**
     * 是否厂直商品
     */
    private String isFactoryShip;
    /**
     * 商品税率
     */
    private String taxInfo;
    /**
     * 商品名称
     */
    private String name;
    /**
     * 规格参数
     */
    private String seoModel;
    /**
     * 商品上下架状态 (1上架 0下架)
     */
    private Integer state;
    /**
     * 分类
     */
    private List<String> category;
    /**
     * 商品编码
     */
    private Long sku;
    /**
     * 商品详情页
     */
    private String introduction;
    /**
     * 是否自营
     */
    private Integer isSelf;

    /**
     * 所属协议编号
     */
    private String agrCode;
    /**
     * 京东自营商品编码
     */
    private String jdSku;
    /**
     * 三方同品链接
     */
    private String sameSkuUrl;

    /**
     * 协商单编号
     **/
    private String consultNo;
    /**
     * 协商单类型
     * 1 询价、2 竞价、3 议价
     **/
    private Integer consultType;
    /**
     * 报价明细编码
     **/
    private String quoteItemCode;

    /**
     * 包装内的数量及单位
     */
    private String wareNum;
    /**
     * 包装单位
     */
    private String ware;
    /**
     * 商品短名称
     */
    private String shortName;
}

==> basic-utils-4.0.0-20251217.034144-118-sources.jar: com/tydic/dyc/pro/base/utils/esb/DycProBaseCallEsbUtilGetSkuDetailForJdResultBO.java <==
package com.tydic.dyc.pro.base.utils.esb;

import lombok.Data;

import java.io.Serializable;
import java.util.List;

/**
 * @Author yuhao
 * @Date 2025/6/10 11:32
 * @Description:
 **/
@Data
public class DycProBaseCallEsbUtilGetSkuDetailForJdResultBO implements Serializable {

    private static final long serialVersionUID = 3007998057922435121L;
    /**
     * 品牌名称
     */
    private String brandName;
    /**
     * 主图
     */
    private String imagePath;
    /**
     * 属性信息
     */
    private List<DycProBaseCallEsbUtilSkuParamForJdBO> paramJson;
    /**
     * 商品最小起购量
     */
    private String LowestBuy;
    /**
     * 重量
     */
    private String weight;
    /**
     * 商品69条码
     */
    private String upc69;
    /**
     * UPC码区分实物、图书、音像、三种场景
     */
    private String upc;
    /**
     * 包装清单
     */
    private String wareQD;
    /**
     * 售卖计量单位
     */
    private String saleUnit;
    /**
     * 是否厂直商品
     */
    private String isFactoryShip;
    /**
     * 商品税率
     */
    private String taxInfo;
    /**
     * 商品名称
     */
    private String name;
    /**
     * 规格参数
     */
    private String seoModel;
    /**
     * 商品上下架状态 (1上架 0下架)
     */
    private Integer state;
    /**
     * 分类
     */
    private List<String> category;
    /**
     * 商品编码
     */
    private Long sku;
    /**
     * 商品详情页
     */
    private String introduction;
    /**
     * 是否自营
     */
    private Integer isSelf;
    /**
     * 型号
     */
    private String model;
    /**
     * 所属协议编号
     */
    private String agrCode;
    /**
     * 商品短名称
     */
    private String shortName;
    /**
     * 京东自营商品编码
     */
    private String jdSku;
    /**
     * 自报京东折扣率
     */
    private String jdDiscountRate;
    /**
     * 三方同品链接
     */
    private String sameSkuUrl;
    /**
     * 包装内的数量及单位
     */
    private String wareNum;
    /**
     * 包装单位
     */
    private String ware;
    /**
     * 产地
     */
    private String productArea;

    /**
     * 上游供应商注册资本是否大于100w
     */
    private Integer upSupCapital;


}
